summaryrefslogtreecommitdiffstats
path: root/kexi/widget/pixmapcollection.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-04 14:05:40 -0600
committerTimothy Pearson <[email protected]>2013-02-04 14:05:40 -0600
commit1d4158dd755a445fd42f2db7db5abab8084175cd (patch)
tree71ca5f966ca25d2a47b66ae27f7bb06c34d190bf /kexi/widget/pixmapcollection.h
parent391e0b69f256bab8971430050c65f0e6e7eea9be (diff)
downloadkoffice-1d4158dd755a445fd42f2db7db5abab8084175cd.tar.gz
koffice-1d4158dd755a445fd42f2db7db5abab8084175cd.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'kexi/widget/pixmapcollection.h')
-rw-r--r--kexi/widget/pixmapcollection.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kexi/widget/pixmapcollection.h b/kexi/widget/pixmapcollection.h
index 7f900866..28629be1 100644
--- a/kexi/widget/pixmapcollection.h
+++ b/kexi/widget/pixmapcollection.h
@@ -32,8 +32,8 @@
#include <kurl.h>
class TQPixmap;
-class KIconView;
-class KIconButton;
+class TDEIconView;
+class TDEIconButton;
class KLineEdit;
class TQDomNode;
@@ -50,7 +50,7 @@ class KEXIEXTWIDGETS_EXPORT PixmapCollection : public TQObject
~PixmapCollection() {;}
TQString addPixmapPath(const KURL &url);
- TQString addPixmapName(const TQString &name, int size = KIcon::SizeMedium);
+ TQString addPixmapName(const TQString &name, int size = TDEIcon::SizeMedium);
void removePixmap(const TQString &name);
bool contains(const TQString &name);
@@ -97,7 +97,7 @@ class KEXIEXTWIDGETS_EXPORT PixmapCollectionEditor : public KDialogBase
private:
enum { BNewItemPath = 101, BNewItemName, BDelItem};
- KIconView *m_iconView;
+ TDEIconView *m_iconView;
TQIntDict<TQToolButton> m_buttons;
PixmapCollection *m_collection;
};
@@ -122,7 +122,7 @@ class KEXIEXTWIDGETS_EXPORT PixmapCollectionChooser : public KDialogBase
private:
PixmapCollection *m_collection;
- KIconView *m_iconView;
+ TDEIconView *m_iconView;
};
//! A simple dialog to choose a KDE icon
@@ -145,15 +145,15 @@ class KEXIEXTWIDGETS_EXPORT LoadIconDialog : public KDialogBase
private:
KLineEdit *m_nameInput;
- KIconButton *m_button;
+ TDEIconButton *m_button;
};
-//! A Special KIconViewItem that holds the name of its associated pixmap (to allow renaming)
-class KEXIEXTWIDGETS_EXPORT PixmapIconViewItem : public KIconViewItem
+//! A Special TDEIconViewItem that holds the name of its associated pixmap (to allow renaming)
+class KEXIEXTWIDGETS_EXPORT PixmapIconViewItem : public TDEIconViewItem
{
public:
- PixmapIconViewItem(KIconView *parent, const TQString &text, const TQPixmap &icon)
- : KIconViewItem(parent, text, icon) { m_name = text; }
+ PixmapIconViewItem(TDEIconView *parent, const TQString &text, const TQPixmap &icon)
+ : TDEIconViewItem(parent, text, icon) { m_name = text; }
~PixmapIconViewItem() {;}
void setName(const TQString &name) { m_name = name; }